===========================
Developing gocept.loginuser
===========================

:Author:
    `gocept <http://gocept.com/>`_ <mail@gocept.com>

:PyPI page:
    https://pypi.org/project/gocept.loginuser/

:Issues:
    https://github.com/gocept/gocept.loginuser/issues

:Source code:
    https://github.com/gocept/gocept.loginuser

:Current change log:
    https://raw.githubusercontent.com/gocept/gocept.loginuser/master/CHANGES.rst
